
Welcome to cx_Freeze's documentation!
=====================================

**cx_Freeze** creates standalone executables from Python scripts, with the same
performance, is cross-platform and should work on any platform that Python_
itself works on.

.. list-table::
   :header-rows: 1
   :widths: 300 300 200

   * - cx_Freeze version
     - Python version
     - Status
   * - cx_Freeze 6.9 to 6.13
     - Python 3.6 to 3.10
     - supported
   * - cx_Freeze 6.4 to 6.8
     - Python 3.6 to 3.9
     - unsupported
   * - cx_Freeze 6.1 to 6.3
     - Python 3.5 to 3.8
     - unsupported
   * - cx_Freeze 6.0
     - Python 3.5 to 3.7
     - unsupported
   * - cx_Freeze 5.1.1
     - Python 2.7
     - unsupported

**cx_Freeze** is distributed under an open-source :ref:`license <license>` (the PSF license).

Contents:

.. toctree::
   :maxdepth: 2

   overview.rst
   installation.rst
   setup_script.rst
   script.rst
   faq.rst
   releasenotes.rst
   development/index.rst
   license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _py2exe: https://pypi.org/project/py2exe/
.. _py2app: https://pypi.org/project/py2app/
.. _Python: https://www.python.org/
